summaryrefslogtreecommitdiffstats
path: root/buildtools/autotools/kfiledndiconview.h
diff options
context:
space:
mode:
Diffstat (limited to 'buildtools/autotools/kfiledndiconview.h')
-rw-r--r--buildtools/autotools/kfiledndiconview.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/buildtools/autotools/kfiledndiconview.h b/buildtools/autotools/kfiledndiconview.h
index 65edd91a..e2b3402e 100644
--- a/buildtools/autotools/kfiledndiconview.h
+++ b/buildtools/autotools/kfiledndiconview.h
@@ -18,8 +18,8 @@
#ifndef KFILEDNDICONVIEW_H
#define KFILEDNDICONVIEW_H
-#include <qwidget.h>
-#include <qtimer.h>
+#include <tqwidget.h>
+#include <tqtimer.h>
#include <kfileiconview.h>
#include <kurldrag.h>
@@ -37,7 +37,7 @@ class KFileDnDIconView : public KFileIconView
Q_OBJECT
public: // Public methods
- KFileDnDIconView( QWidget *parent = 0, const char *name = 0 );
+ KFileDnDIconView( TQWidget *parent = 0, const char *name = 0 );
virtual ~KFileDnDIconView();
/**
@@ -77,15 +77,15 @@ public: // Public methods
return m_useAutoOpenTimer;
}
- virtual void readConfig( KConfig*, const QString& group = QString::null );
- virtual void writeConfig( KConfig*, const QString& group = QString::null );
+ virtual void readConfig( KConfig*, const TQString& group = TQString::null );
+ virtual void writeConfig( KConfig*, const TQString& group = TQString::null );
signals:
/**
* Emitted whenever an decodable item is dropped in the view.
* Note: The @ref QDropEvent contains a @ref KURLDrag object.
*/
- void dropped( QDropEvent* );
+ void dropped( TQDropEvent* );
protected slots:
/**
@@ -94,16 +94,16 @@ protected slots:
void slotOpenFolder();
protected:
- virtual void contentsDragEnterEvent( QDragEnterEvent *e );
- virtual void contentsDragMoveEvent( QDragMoveEvent *e );
- virtual void contentsDragLeaveEvent( QDragLeaveEvent *e );
- virtual void contentsDropEvent( QDropEvent* e );
+ virtual void contentsDragEnterEvent( TQDragEnterEvent *e );
+ virtual void contentsDragMoveEvent( TQDragMoveEvent *e );
+ virtual void contentsDragLeaveEvent( TQDragLeaveEvent *e );
+ virtual void contentsDropEvent( TQDropEvent* e );
/**
* Creates a @ref QDragObject containing all urls of the selected @ref KFileItem of the view,
* @returns the @ref QDragObject
*/
- virtual QDragObject* dragObject();
+ virtual TQDragObject* dragObject();
/**
*Creates the drag item and starts the drag
@@ -113,14 +113,14 @@ protected:
/**
*@returns true if we can decode the drag and support the action
*/
- virtual bool acceptDrag( QDropEvent* event ) const;
+ virtual bool acceptDrag( TQDropEvent* event ) const;
protected:
- QTimer m_autoOpenTimer;
+ TQTimer m_autoOpenTimer;
int m_autoOpenTime;
bool m_useAutoOpenTimer;
- QIconViewItem* m_dropItem;
+ TQIconViewItem* m_dropItem;
bool m_dndEnabled;
};
#endif
@@ -77,15 +77,15 @@ public: // Public methods
/**
* Emitted whenever an decodable item is dropped in the view.
- * Note: The @ref QDropEvent contains a @ref KURLDrag object.
+ * Note: The @ref TQDropEvent contains a @ref KURLDrag object.
*/
@@ -94,16 +94,16 @@ protected slots:
/**
- * Creates a @ref QDragObject containing all urls of the selected @ref KFileItem of the view,
+ * Creates a @ref TQDragObject containing all urls of the selected @ref KFileItem of the view,
* @returns the @ref QDragObject
*/